%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Correct   GLOBAL PUSHOVER CURVE PLOTTING  FOR 13-Story Steel Building
%
% Last Modified : March 04
% by Erol Kalkan
% Description : This file takes bottom storey level shear forces at column
% ends and sum them up then compare with SAP2000 pushover curve; in the next figure
% it draws base shear coefficient vs roof drift
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
close all; clear all; clc;
W=3036.7; % TOTAL WEIGHT OF STRUCTURE
h=990;
nstory=6;

g=386.2;
%*****************************************************
alfa=0.1; % IMPORTANT FOR SDOF SYSTEM, POST YIELD STRAIN HARDENING
Ductility=[1 1.5 2 3 4 5 6]; % DUCTILITY LEVELS
nduct=length(Ductility);

% NOTE: Based on Sd not Dn
%**************************************************************************
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% LOAD STORY SHEAR FORCES 
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
load Fl_1_Cols_Forces.out; sh=Fl_1_Cols_Forces;
    s1=sh(:,1)+sh(:,7)+sh(:,13)+sh(:,19)+sh(:,25)+sh(:,31)+sh(:,37);
load Fl_2_Cols_Forces.out; sh=Fl_2_Cols_Forces;
    s2=sh(:,1)+sh(:,7)+sh(:,13)+sh(:,19)+sh(:,25)+sh(:,31)+sh(:,37);
load Fl_3_Cols_Forces.out; sh=Fl_3_Cols_Forces;
    s3=sh(:,1)+sh(:,7)+sh(:,13)+sh(:,19)+sh(:,25)+sh(:,31)+sh(:,37);
load Fl_4_Cols_Forces.out; sh=Fl_4_Cols_Forces;
    s4=sh(:,1)+sh(:,7)+sh(:,13)+sh(:,19)+sh(:,25)+sh(:,31)+sh(:,37);
load Fl_5_Cols_Forces.out; sh=Fl_5_Cols_Forces;
    s5=sh(:,1)+sh(:,7)+sh(:,13)+sh(:,19)+sh(:,25)+sh(:,31)+sh(:,37);
load Fl_6_Cols_Forces.out; sh=Fl_6_Cols_Forces;
    s6=sh(:,1)+sh(:,7)+sh(:,13)+sh(:,19)+sh(:,25)+sh(:,31)+sh(:,37);

shear=[s1 s2 s3 s4 s5 s6];
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% LOAD STORY DISPLACEMENT
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
load Floor_6_Displ.out; disp6=Floor_6_Displ(:,1);
load Floor_5_Displ.out; disp5=Floor_5_Displ(:,1);
load Floor_4_Displ.out; disp4=Floor_4_Displ(:,1);
load Floor_3_Displ.out; disp3=Floor_3_Displ(:,1);
load Floor_2_Displ.out; disp2=Floor_2_Displ(:,1);
load Floor_1_Displ.out; disp1=Floor_1_Displ(:,1);

dis=[disp1 disp2 disp3 disp4 disp5 disp6];

%**************************************************************************
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% INCREMENTAL DISPLACEMENT AT EACH STORY LEVEL
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
for j=1:nstory;
    ddis(1,j)=dis(1,j);
    for i=2:length(dis);
        ddis(i,j)=dis(i,j)-dis(i-1,j);
    end
end
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% STATIC FORCE AT EACH STORY LEVEL
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
for j=1:nstory-1;
    for i=1:length(shear);
        staticF(i,j)=shear(i,j)-shear(i,j+1);
    end
end
staticF(:,nstory)=shear(:,nstory);
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% ENERGY COMPUTATION AT EACH STORY LEVEL
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
for j=1:nstory;
    for i=1:length(ddis);
        dEn(i,j)=ddis(i,j)*staticF(i,j);
    end
end
    dE=sum(dEn,2);
    V=shear(:,1);
    DD=0;
    for i=1:length(dE);
        deltaDn(i)=dE(i)/V(i);
    end 
    Dn=cumsum(deltaDn)*-1;
    
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
%       BASE SHEAR FORCES and ROOF DISPL. 
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
disp=disp6; 

figure(1);
subplot(2,1,1);
plot(disp/h,abs(s1)/W,'r'); grid;
xlabel('Roof Drift'); ylabel('Base Shear Coefficient/W');

output=[abs(s1)/W disp/h];
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
% ADRS PART
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
m=[0.258*6 0 0 0 0 0
0 0.22*6 0 0 0 0
0 0 0.22*6 0 0 0
0 0 0 0.22*6 0 0
0 0 0 0 0.22*6 0
0 0 0 0 0 0.1725*6];

Mtot=sum(sum(m)); % TOTAL MASS
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
% COMPUTE ALFA and Fi_Roof_n
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
load Mode1.gam;
load Mode2.gam;
load Mode3.gam;

    for j=1:length(Mode1);
        alfa1(j)=Mode1(j)^2/Mtot;
        alfa2(j)=Mode2(j)^2/Mtot;
        alfa3(j)=Mode3(j)^2/Mtot;
    end
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
% MODE SELECTION
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    Mode=Mode2;
    alfa=alfa2;
    Eigen=load ('Eigen_2_46.eig'); 
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    for j=1:length(Mode);
        Sa(j)=(abs(s1(j)))/W/alfa(j); % INTO g
%        Sd(j)=disp(j)/(Mode(j)*Eigen);
        Sd(j)=disp(j)/(Mode(j)*Eigen(j));
    end
    Sa=Sa'; %Sd=Sd'*-1;
    
    subplot(2,1,2);
    plot(Sd,Sa,'ro'); grid; xlabel('Sd'); ylabel('Sa'); hold;
    plot(Dn,Sa,'o'); legend('Conventional ADRS','Energy Based ADRS');

% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
% DEMAND = INELASTIC SPECTRA 
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% SECANT PERIOD COMPUTATION OF THE CAPACITY CURVE
    Sd=Dn;

    for j=1:length(Mode);
        T(j)=2*pi/(Sa(j)*386.2/Sd(j))^0.5;
    end
    T=T';

SDSA=load ('sdsa_mode2.dat');

for i=1:nduct;
    SAA(:,i)=SDSA(:,i*2);
    SDD(:,i)=SDSA(:,(2*i-1));
end
% SECANT PERIOD COMPUTATION FOR EACH DUCTILITY LEVEL
for i=1:nduct;
    for j=1:100;
        tsecant(j,i)=2*pi/(SAA(j,i)/SDD(j,i))^0.5;
    end
end
%*****************************************************
figure(3);
subplot(2,4,1); hold;
for i=1:7;
plot(tsecant(:,i),SDD(:,i)); plot(T,Sd,'ro'); xlabel('Period (sec)'); ylabel('Sd (inch)'); 
end

for i=1:7;
subplot(2,4,i+1); 
plot(tsecant(:,i),SDD(:,i)); hold; plot(T,Sd,'ro'); xlabel('Period (sec)'); ylabel('Sd (inch)'); 
end

%*****************************************************

figure(5);
subplot(2,4,1); hold;
for i=1:7;
plot(SDD(:,i),SAA(:,i)); plot(Sd,Sa*g,'ro'); xlabel('Sd (sec)'); ylabel('Sa (inch)'); 
end

for i=1:7;
subplot(2,4,i+1); 
plot(SDD(:,i),SAA(:,i)); hold; plot(Sd,Sa*g,'ro'); xlabel('Sd (sec)'); ylabel('Sa (inch)'); 
end

%--------------------------------------------------------------------------
% ADDITIONAL COMPUTATIONS
% ALLAHIM SEN RAST GETIR
%--------------------------------/o\/o\-------------------------------------








